@@ -14,6 +14,11 @@
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn {Function File} issparse (@var{s})
+## Returns true since a blksparse is sparse by definition.
+## @end deftypefn
+
 function yes = issparse (s)
   yes = true;
 endfunction
